package com.ibm.jps.util;

import java.text.DateFormat;
import java.util.Date;
import java.util.Locale;

/**
 * Contains general utilities.
 */
public class RSMUtil {

    /**
     * Given an input string of the type "com.company.project.AClass", getPath will return
     * "com.company.project" (or an empty string if the input string is "AClass").
     * 
     * @param name The input string (e.g. "com.company.project.AClass")
     * @return The matching path (e.g. "com.company.project") or ""
     */
    public static String getPath(String name) {
        int pos = name.lastIndexOf(".");
        if (pos > 0)
            return name.substring(0, pos);
        else
            return "";
    }

    /**
     * Given an input string of the type "com?company?project?AClass" where "?" is used as a separator, 
     * getPath will return "com?company?project" (or an empty string if the input string is "AClass").
     * 
     * @param name The input string (e.g. "com?company?project?AClass")
     * @param fileSeparator The file separator (e.g. "?")
     * @return The matching path (e.g. "com?company?project") or ""
     */
    public static String getPath(String name, char fileSeparator) {
        int pos = name.lastIndexOf(fileSeparator);
        if (pos > 0)
            return name.substring(0, pos);
        else
            return "";
    }

    /**
     * Given an input string of the type "com.company.project.AClass", getSimpleName will return
     * "AClass" (or the string itself if the input string is "AClass").
     * 
     * @param name The input string (e.g. "com.company.project.AClass")
     * @return The 'leaf' name (e.g. "AClass")
     */
    public static String getSimpleName(String name) {
        int pos = name.lastIndexOf(".");
        if (pos > 0)
            return name.substring(pos + 1);
        else
            return name;
    }

    /**
     * Given an input string of the type "com?company?project?AClass" where "?" is used as a separator, 
     * getSimpleName will return "AClass" (or the string itself if the input string is "AClass").
     * 
     * @param name The input string (e.g. "com?company?project?AClass")
     * @param fileSeparator The file separator (e.g. "?")
     * @return The 'leaf' name (e.g. "AClass")
     */
    public static String getSimpleName(String name, char fileSeparator) {
        int pos = name.lastIndexOf(fileSeparator);
        if (pos > 0)
            return name.substring(pos + 1);
        else
            return name;
    }

    /**
     * Capitalizes the first letter of the specified string
     * 
     * @param name The input string
     * @return The string with the first letter capitalized
     */
    public static String firstCharToUpperCase(String name) {
        return name.substring(0, 1).toUpperCase() + name.substring(1);
    }

    /**
     * Changes the first letter of the specified string to lower case
     * 
     * @param name The input string
     * @return The string with the first letter changed to lower case
     */
    public static String firstCharToLowerCase(String name) {
        return name.substring(0, 1).toLowerCase() + name.substring(1);
    }

    /**
     * Returns the current date as a string formatted the specified locale
     *  
     * @param currentLocale The locale to use
     * @return The formatted date
     */
    public static String getDate(Locale currentLocale) {
        Date today = new Date();
        DateFormat formatter = DateFormat.getDateTimeInstance(DateFormat.DEFAULT, DateFormat.DEFAULT, currentLocale);
        return formatter.format(today);
    }

    /**
     * Replaces in the input string all occurences of the <em>from</em> expression by the <em>to</em> expression
     * 
     * @param inputString The input string
     * @param fromExp The substring to replace
     * @param toExp The replacement text
     * @return The output string
     */
    public static String replaceAllSubstrings(String inputString, String fromExp, String toExp) {
        if (fromExp.equals(inputString)) return toExp;
        int pos;
        int prev = 0;
        String res = "";
        do {
            pos = inputString.indexOf(fromExp, prev);
            if (pos == -1) {
                res = res + inputString.substring(prev);
            } else {
                if (pos > prev) res = res + inputString.substring(prev, pos);
                res = res + toExp;
            }
            prev = pos + fromExp.length();
        } while (pos >= 0);
        return res;
    }

	/**
	 * Converts an input string such as " the project name" to "theProjectName"
	 * 
	 * @param inputString The input string (e.g. " the project name")
	 * @return The output string (e.g. "theProjectName")
	 */
	public static String convertToCamelCase(String inputString) {
		String outputString = "";
		inputString = inputString.trim();
		int cc = inputString.length();
		boolean convertToUppercase = true;
		for (int i = 0; i < cc; i++) {
			char c = inputString.charAt(i);
			if (c != ' ') {
				if (convertToUppercase) {
					outputString += Character.toUpperCase(c);
				} else {
					outputString += c;
				}
				convertToUppercase = false;
			} else {
				convertToUppercase = true;
			}
		}
		return outputString;
	}
}
